@@ -2,6 +2,7 @@ from pathlib import Path, PurePosixPath
 import datetime
 import logging
 from uuid import UUID
+import itertools
 
 import requests.exceptions
 
@@ -179,6 +180,25 @@ class RegistrationClient:
         eid = UUID(self.create_session(session_path)['url'][-36:]) if register else None
         return session_path, eid
 
+    def find_files(self, session_path):
+        """
+        Returns an generator of file names that match one of the dataset type patterns in Alyx
+
+        Parameters
+        ----------
+        session_path : str, pathlib.Path
+            The session path to search
+
+        Returns
+        -------
+        Iterable of file paths that match the dataset type patterns in Alyx
+        """
+        session_path = Path(session_path)
+        types = (x['filename_pattern'] for x in self.dtypes if x['filename_pattern'])
+        dsets = itertools.chain.from_iterable(session_path.rglob(x) for x in types)
+        return (x for x in dsets if x.is_file() and
+                any(x.name.endswith(y) for y in self.file_extensions))
+
     def assert_subject_exists(self, subject: str) -> None:
         """Raise an error if a given subject doesn't exist on Alyx database
 
@@ -229,6 +249,25 @@ class RegistrationClient:
             for x in user:
                 self.assert_user_exists(x)
 
+    def assert_repository_exists(self, name):
+        """
+
+        Parameters
+        ----------
+        name
+
+        Returns
+        -------
+
+        """
+        try:
+            self.one.alyx.rest('repository', 'read', id=name, no_cache=True)
+        except requests.exceptions.HTTPError as ex:
+            if '404' not in str(ex):
+                raise ex
+            else:
+                raise alferr.ALFError(f'Repository "{name}" doesn\'t exist in Alyx')
+
     @staticmethod
     def ensure_ISO8601(date) -> str:
         """Ensure provided date is ISO 8601 compliant
@@ -328,19 +367,8 @@ class RegistrationClient:
         F = []  # empty list whose keys will be relative paths and content filenames
         md5s = []
         file_sizes = []
-        for fn in _glob_session(ses_path):
-            if fn.suffix in EXCLUDED_EXTENSIONS:
-                _logger.debug('Excluded: ', str(fn))
-                continue
-            if not _check_filename_for_registration(fn, self.registration_patterns):
-                _logger.warning('No matching dataset type for: ' + str(fn))
-                continue
-            if fn.suffix not in self.file_extensions:
-                _logger.warning('No matching dataformat (ie. file extension) for: ' + str(fn))
-                continue
-            if not _register_bool(fn.name, file_list):
-                _logger.debug('Not in filelist: ' + str(fn))
-                continue
+
+        for fn in self.find_files(ses_path) if file_list is True else file_list:
             try:
                 assert (str(gen_rel_path) in str(fn))
             except AssertionError as e:
@@ -479,3 +507,22 @@ def _register_bool(fn, file_list):
     if isinstance(file_list, str):
         file_list = [file_list]
     return any([str(fil) in fn for fil in file_list])
+
+
+def _glob_session(ses_path):
+    """
+    Glob for files to be registered on an IBL session
+
+    Parameters
+    ----------
+    ses_path : str, pathlib.Path
+        A session path
+
+    Returns
+    -------
+    A list of files to potentially be registered
+    """
+    fl = []
+    for gp in REGISTRATION_GLOB_PATTERNS:
+        fl.extend(list(Path(ses_path).glob(gp)))
+    return fl
